==> apache-cxf-3.4.7-src.tar.gz: apache-cxf-3.4.7-src/systests/databinding/src/test/java/org/apache/cxf/systest/jaxb/model/ExtendedWidgetWithMime.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.systest.jaxb.model;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlMimeType;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


@XmlType(name = "extendedwidgetWithMime", namespace = "http://cxf.org.apache/model")
@XmlRootElement(name = "extendedwidgetWithMime", namespace = "http://cxf.org.apache/model")
@XmlAccessorType(XmlAccessType.FIELD)
public class ExtendedWidgetWithMime extends Widget {


    @XmlMimeType("application/octet-stream")
    private byte[] xmlData;


    /**
     * @return the extended
     */
    public byte[] getXmlData() {
        return xmlData;
    }

    /**
     * @param extended the extended to set
     */
    public void setXmlData(byte[] xmlData) {
        this.xmlData = xmlData;
    }

}

==> apache-cxf-4.0.7-src.tar.gz: apache-cxf-4.0.7-src/systests/databinding/src/test/java/org/apache/cxf/systest/jaxb/model/ExtendedWidgetWithMime.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.systest.jaxb.model;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlMimeType;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;


@XmlType(name = "extendedwidgetWithMime", namespace = "http://cxf.org.apache/model")
@XmlRootElement(name = "extendedwidgetWithMime", namespace = "http://cxf.org.apache/model")
@XmlAccessorType(XmlAccessType.FIELD)
public class ExtendedWidgetWithMime extends Widget {


    @XmlMimeType("application/octet-stream")
    private byte[] xmlData;


    /**
     * @return the extended
     */
    public byte[] getXmlData() {
        return xmlData;
    }

    /**
     * @param extended the extended to set
     */
    public void setXmlData(byte[] xmlData) {
        this.xmlData = xmlData;
    }

}
